@@ -136,7 +136,7 @@ class TestYq(unittest.TestCase):
             self.run_yq("{}", ["--indentless", "-y", ".a=$ARGS.positional", "--args", "a", "b"]), "a:\n- a\n- b\n"
         )
         self.assertEqual(self.run_yq("{}", ["-y", ".a=$ARGS.positional", "--args", "a", "b"]), "a:\n  - a\n  - b\n")
-        self.assertEqual(self.run_yq("{}", [".", "--jsonargs", "a", "b"]), "")
+        self.assertEqual(self.run_yq("{}", [".", "--jsonargs", "{}", "{}"]), "")
 
     def test_short_option_separation(self):
         # self.assertEqual(self.run_yq('{"a": 1}', ["-yCcC", "."]), "a: 1\n") - Fails on 2.7 and 3.8
@@ -185,7 +185,7 @@ class TestYq(unittest.TestCase):
         with io.open(cfn_filename) as fh:
             self.assertEqual(self.run_yq("", ["-Y", ".", cfn_filename]), fh.read())
 
-    def test_in_place(self):
+    def test_in_place_yaml(self):
         with tempfile.NamedTemporaryFile() as tf, tempfile.NamedTemporaryFile() as tf2:
             tf.write(b"- foo\n- bar\n")
             tf.seek(0)
@@ -202,6 +202,13 @@ class TestYq(unittest.TestCase):
             self.assertEqual(tf.read(), b"foo\n...\n")
             self.assertEqual(tf2.read(), b"foo\n...\n")
 
+    def test_in_place_toml(self):
+        with tempfile.NamedTemporaryFile() as tf:
+            tf.write(b'[GLOBAL]\nversion="1.0.0"\n')
+            tf.seek(0)
+            self.run_yq("", ["-i", "-t", '.GLOBAL.version="1.0.1"', tf.name], input_format="toml")
+            self.assertEqual(tf.read(), b'[GLOBAL]\nversion = "1.0.1"\n')
+
     def test_explicit_doc_markers(self):
         test_doc = os.path.join(os.path.dirname(__file__), "doc.yml")
         self.assertTrue(self.run_yq("", ["-y", ".", test_doc]).startswith("yaml_struct"))
@@ -210,7 +217,12 @@ class TestYq(unittest.TestCase):
 
     def test_xq(self):
         self.assertEqual(self.run_yq("<foo/>", ["."], input_format="xml"), "")
+        self.assertEqual(self.run_yq("<foo/>", ["--xml-item-depth=2", "."], input_format="xml"), "")
+        self.assertEqual(self.run_yq("<foo/>", ["--xml-dtd", "."], input_format="xml"), "")
         self.assertEqual(self.run_yq("<foo/>", ["-x", ".foo.x=1"], input_format="xml"), "<foo>\n  <x>1</x>\n</foo>\n")
+        self.assertTrue(self.run_yq("<foo/>", ["-x", "--xml-dtd", "."], input_format="xml").startswith("<?xml"))
+        self.assertTrue(self.run_yq("<foo/>", ["-x", "--xml-root=R", "."], input_format="xml").startswith("<R>"))
+        self.assertEqual(self.run_yq("<foo/>", ["--xml-force-list=foo", "."], input_format="xml"), "")
 
         self.assertEqual(self.run_yq("<a><b/></a>", ["-y", "."], input_format="xml"), "a:\n  b: null\n")
         self.assertEqual(
